============
 Change log
============

0.3 (2014-02-07)
----------------

- Move to GitHub.

- Added missing ``zope.testing`` test depenency declaration.

- Added this change log.


0.2 (2008-01-26)
----------------

- Initial release.

